package com.shxy.xymanager_service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateField;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageInfo;
import com.google.common.collect.Lists;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.constant.Constants;
import com.shxy.xymanager_common.dto.*;
import com.shxy.xymanager_common.entity.*;
import com.shxy.xymanager_common.enums.CommonStatus;
import com.shxy.xymanager_common.exception.Asserts;
import com.shxy.xymanager_common.model.*;
import com.shxy.xymanager_common.page.PageUtils;
import com.shxy.xymanager_common.util.CmaUtil;
import com.shxy.xymanager_common.util.MyDateUtils;
import com.shxy.xymanager_common.util.ProcessExecUtils;
import com.shxy.xymanager_common.util.StringUtils;
import com.shxy.xymanager_common.vo.*;
import com.shxy.xymanager_dao.dao.*;
import com.shxy.xymanager_service.cache.XyCache;
import com.shxy.xymanager_service.service.TerminalPhotoService;
import com.shxy.xymanager_service.service.TerminalScheduleRuleService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.math.BigInteger;
import java.util.*;

/**
 * 装置图片实现层
 */
@Service
@Slf4j
public class TerminalPhotoServiceImpl implements TerminalPhotoService {

    @Autowired
    TerminalPhotoDao terminalPhotoDao;

    @Autowired
    TerminalsDao terminalsDao;

    @Autowired
    DyLevelDao dyLevelDao;

    @Autowired
    LinesDao linesDao;

    @Autowired
    TowerDao towerDao;

    @Autowired
    TerminalChannelsDao terminalChannelsDao;

    @Autowired
    TerminalScheduleRuleService terminalScheduleRuleService;

    @Value("${cma.server}")
    private String server;

    @Value("${cma.port}")
    private int port;

    @Value("${photo.address}")
    private String photoaddress;

    @Value("${video.address}")
    private String videoaddress;


    /**
     * 根据装置id和通道id获取图片
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<TerminalPhotoListModel> getTerminalPhotoList(TerminalAndChannelIdAndTimeVo vo) {
        TerminalPhotoListModel model = new TerminalPhotoListModel();
        Date time = vo.getTime();
        DateTime begindateTime = MyDateUtils.beginOfDay(time);
        DateTime enddateTime = MyDateUtils.endOfDay(time);
        long start = MyDateUtils.TimeMillSecond2Second(begindateTime);
        long end = MyDateUtils.TimeMillSecond2Second(enddateTime);
        boolean empty1 = CollectionUtil.isEmpty(vo.getChannelid());
        List<TerminalPhoto> list = new ArrayList<>();
        if (!empty1) {
            list = terminalPhotoDao.selectPhotoList(vo.getTerminalid(), vo.getChannelid(), BigInteger.valueOf(start), BigInteger.valueOf(end));
        }
        boolean empty = CollectionUtil.isEmpty(list);
        model.setTime(vo.getTime());
        model.setNum(list.size());
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            List<TerminalPhotoListModel.PhotoBean> beans = new ArrayList<>();
            Map<Integer, TerminalChannels> termchannelMap = XyCache.termchannelMap;
            Map<String, TerminalChannelMapper> termchannelMapMap = XyCache.termchannelMapMap;
            for (TerminalPhoto item : list) {
                Integer mediaType = item.getMediaType();
                if (mediaType == 0 || mediaType == 1) {
                    TerminalPhotoListModel.PhotoBean photoBean = new TerminalPhotoListModel.PhotoBean();
                    Integer termId = item.getTermId();
                    Integer channelId = item.getChannelId();

                    photoBean.setChannelId(channelId);
                    photoBean.setFileSize(item.getFileSize());
                    photoBean.setHeight(item.getHeight());
                    photoBean.setMediaType(item.getMediaType());
                    if (mediaType == 0) {
                        photoBean.setPath(photoaddress + item.getPath());
                    } else {
                        photoBean.setPath(videoaddress + item.getPath());
                        if (StringUtils.isNotBlank(item.getThumb())) {
                            photoBean.setThumb(videoaddress + item.getThumb());
                        }
                    }
                    photoBean.setChannelName(termchannelMap.get(channelId).getChannelName());
                    if (termchannelMapMap != null) {
                        TerminalChannelMapper terminalChannelMapper = termchannelMapMap.get(termId + "#" + channelId);
                        if (terminalChannelMapper != null) {
                            photoBean.setAlias(terminalChannelMapper.getAlias());
                        } else {
                            photoBean.setAlias("");
                        }
                    } else {
                        photoBean.setAlias("");
                    }
                    photoBean.setId(item.getId());
                    photoBean.setTermId(termId);
                    photoBean.setWidth(item.getWidth());
                    photoBean.setPresetId(item.getPresetId());
                    long phototime = MyDateUtils.TimeSecond2MillSecond(item.getPhotoTime().longValue());
                    photoBean.setPhotoTime(MyDateUtils.date(phototime));
                    long rectime = MyDateUtils.TimeSecond2MillSecond(item.getRecvTime().longValue());
                    photoBean.setRecvTime(MyDateUtils.date(rectime));
                    beans.add(photoBean);
                }
            }
            model.setList(beans);
        }
        return Asserts.success(model);
    }

    /**
     * 图片查询
     */
    @Override
    public ServiceBody<TerminalPhotoSelectListModel> getPhotoList(TerminalPhotoSelectVo vo) {
        TerminalPhotoSelectListModel model = new TerminalPhotoSelectListModel();
        List<TerminalPhoto> list = new ArrayList<>();
        List<TerminalPhotoSelectListModel.PhotoBean> beans = new ArrayList<>();
        Integer dyid = vo.getDyid();
        Integer lineid = vo.getLineid();
        Integer termid = vo.getTermid();
        Integer towerid = vo.getTowerid();
        Integer channelid = vo.getChannelid();
        int pageindex = vo.getPageindex();
        int pagesize = vo.getPagesize();

        Date starttime = vo.getStarttime();
        Date endtime = vo.getEndtime();
        long start = MyDateUtils.TimeMillSecond2Second(DateTime.of(starttime));
        long end = MyDateUtils.TimeMillSecond2Second(DateTime.of(endtime));
        if (BeanUtil.isEmpty(dyid) || BeanUtil.isEmpty(lineid) || BeanUtil.isEmpty(towerid) || BeanUtil.isEmpty(channelid)) {
            model.setList(beans);
        } else {
            List<Integer> termidlist = new ArrayList<>();
            ArrayList<Integer> channelidlist = new ArrayList<>();

            List<DyAndLineAndTowerAndTermDto> dtos = new ArrayList<>();
            if (dyid == null || dyid.intValue() == 0) {
                PageUtils.SetPage(pageindex, pagesize);
                list = terminalPhotoDao.selectPhotoListByTermList(termidlist, channelidlist, BigInteger.valueOf(start), BigInteger.valueOf(end));
            } else {
                if (lineid == null || lineid.intValue() == 0) {
                    dtos = dyLevelDao.selectDyAndLineAndTowerAnTermList(dyid, null, null, null, CommonStatus.EFFECTIVE.value());
                } else {
                    if (towerid == null || towerid.intValue() == 0) {
                        dtos = dyLevelDao.selectDyAndLineAndTowerAnTermList(dyid, lineid, null, null, CommonStatus.EFFECTIVE.value());
                    } else {
                        if (termid == null || termid.intValue() == 0) {
                            dtos = dyLevelDao.selectDyAndLineAndTowerAnTermList(dyid, lineid, towerid, null, CommonStatus.EFFECTIVE.value());
                        } else {
                            dtos = dyLevelDao.selectDyAndLineAndTowerAnTermList(dyid, lineid, towerid, termid, CommonStatus.EFFECTIVE.value());
                        }
                    }
                }
                for (DyAndLineAndTowerAndTermDto item1 : dtos) {
                    for (LineAndTowerAndTermDto item2 : item1.getList()) {
                        for (TowerAndTermDto item3 : item2.getList()) {
                            for (Terminals item4 : item3.getList()) {
                                termidlist.add(item4.getId());
                            }
                        }
                    }
                }
                if (channelid == null || channelid.intValue() == 0) {

                } else {
                    channelidlist.add(channelid);
                }
                if (termidlist.size() == 0) {

                } else {
                    PageUtils.SetPage(pageindex, pagesize);
                    list = terminalPhotoDao.selectPhotoListByTermList(termidlist, channelidlist, BigInteger.valueOf(start), BigInteger.valueOf(end));
                }
            }

            boolean empty = CollectionUtil.isEmpty(list);
            if (empty) {
                model.setList(new ArrayList<>());
            } else {
                Map<Integer, Terminals> terminalMap = XyCache.terminalMap;
                Map<Integer, LineAndDyNameDto> lineMap = XyCache.lineMap;
                Map<Integer, TerminalChannels> termchannelMap = XyCache.termchannelMap;
                Map<String, TerminalChannelMapper> termchannelMapMap = XyCache.termchannelMapMap;
                for (TerminalPhoto item : list) {
                    TerminalPhotoSelectListModel.PhotoBean photoBean = new TerminalPhotoSelectListModel.PhotoBean();
                    photoBean.setTermid(item.getTermId());
                    Terminals terminals = terminalMap.get(item.getTermId());
                    if (!BeanUtil.isEmpty(terminals)) {
                        photoBean.setDisplayname(terminals.getDisplayName());
                        photoBean.setLineid(terminals.getLineid());
                        photoBean.setLinename(lineMap.get(terminals.getLineid()).getName());
                        photoBean.setChannelid(item.getChannelId());
                        photoBean.setCmdid(terminals.getCmdid());
                        photoBean.setChannnelname(termchannelMap.get(item.getChannelId()).getChannelName());

                        photoBean.setAlias(termchannelMapMap.get(item.getTermId() + "#" + item.getChannelId()).getAlias());
                        photoBean.setMediaType(item.getMediaType());
                        photoBean.setOrginalid(item.getOrginalId());
                        if (item.getMediaType() == 0) {
                            photoBean.setPath(photoaddress + item.getPath());
                        } else {
                            photoBean.setPath(videoaddress + item.getPath());
                        }
                        photoBean.setPresetId(item.getPresetId());
                        long phototime = MyDateUtils.TimeSecond2MillSecond(item.getPhotoTime().longValue());
                        photoBean.setPhotoTime(MyDateUtils.date(phototime));
                        long rectime = MyDateUtils.TimeSecond2MillSecond(item.getRecvTime().longValue());
                        photoBean.setRecvTime(MyDateUtils.date(rectime));
                        beans.add(photoBean);
                    }
                }
                model.setList(beans);
            }
        }
        PageInfo pageData = PageUtils.getPageData(list);
        int currentpage = pageData.getPageNum();
        model.setCurrentpage(currentpage);
        long total = pageData.getTotal();
        model.setTotal(total);

        int pageSize = pageData.getPageSize();
        model.setPagesize(pageSize);
        int pages = pageData.getPages();
        model.setTotalpage(pages);
        return Asserts.success(model);
    }

    /**
     * 根据装置和时间提供给第三方
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<TerminalPhotoListForOpenModel> getPhotoListForOpen(OpenTerminalAndTimeVo vo) {
        String cmdid = vo.getCmdId();
        TerminalPhotoListForOpenModel model = new TerminalPhotoListForOpenModel();

        Terminals terminals = terminalsDao.selectByCmdid(cmdid, CommonStatus.EFFECTIVE.value());
        if (BeanUtil.isEmpty(terminals)) {
            return Asserts.error("没有该装置信息");
        }
        Integer pageindex = vo.getPageIndex();
        Integer pagesize = vo.getPageSize();
        if (BeanUtil.isEmpty(pageindex) || pageindex <= 0) {
            pageindex = 1;
        }
        if (BeanUtil.isEmpty(pagesize) || pagesize <= 0) {
            pagesize = 10;
        }
        PageUtils.SetPage(pageindex, pagesize);
        Date starttime = MyDateUtils.myparseDate(vo.getStartTime());
        long start = 0;
        if (starttime != null) {
            start = MyDateUtils.TimeMillSecond2Second(DateTime.of(starttime));
        }
        Date endtime = MyDateUtils.myparseDate(vo.getEndTime());
        long end = 0;
        if (endtime != null) {
            end = MyDateUtils.TimeMillSecond2Second(DateTime.of(endtime));
        }
        List<TerminalPhoto> list = terminalPhotoDao.selectPhotoListForOpen(terminals.getId(), BigInteger.valueOf(start), BigInteger.valueOf(end));
        boolean empty = CollectionUtil.isEmpty(list);
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            List<TerminalPhotoListForOpenModel.PhotoBean> beans = new ArrayList<>();
            for (TerminalPhoto item : list) {
                TerminalPhotoListForOpenModel.PhotoBean photoBean = new TerminalPhotoListForOpenModel.PhotoBean();
                photoBean.setCmdId(cmdid);
                photoBean.setMediaType(item.getMediaType());
                photoBean.setOrginalId(item.getOrginalId());
//                photoBean.setPath(photoaddress + item.getPath());
                String path = item.getPath();
                if (item.getMediaType() == 0) {
                    photoBean.setPath(photoaddress + path);
                } else {
                    photoBean.setPath(videoaddress + item.getPath());
                }
                if (path != null) {
                    photoBean.setPath(photoaddress + path);
                    String[] split = path.split("/");
                    int length = split.length;
                    String s = split[length - 1];
                    photoBean.setName(s);

                }
                photoBean.setPresetId(item.getPresetId());
                long phototime = MyDateUtils.TimeSecond2MillSecond(item.getPhotoTime().longValue());
                photoBean.setPhotoTime(MyDateUtils.date(phototime));
                beans.add(photoBean);
            }
            model.setList(beans);
        }
        PageInfo pageData = PageUtils.getPageData(list);
        int currentpage = pageData.getPageNum();
        model.setCurrentpage(currentpage);
        long total = pageData.getTotal();
        model.setTotal(total);

        int pageSize = pageData.getPageSize();
        model.setPagesize(pageSize);
        int pages = pageData.getPages();
        model.setTotalpage(pages);
        return Asserts.success(model);
    }

    @Override
    public ServiceBody<Date> getLatestPhoto(TerminalPhotoVo vo) {
        DateTime now = DateTime.now();
//        String cmd = Constants.CMD + "capture --cmdid=" + vo.getCmdid() + " --channel=" + vo.getChannel() + " --preset=255 --type=" + vo.getCaptureType();
        String cmd = CmaUtil.takePic(vo.getCmdid(), vo.getChannel(), vo.getCaptureType());
        ProcessExecUtils.exec(cmd);
        return Asserts.success(now);
    }

    @Override
    public ServiceBody<Boolean> getReturnedPhoto(ReturnedPhotoVo vo) {
        Boolean hasNew = false;
        TerminalPhoto photo = terminalPhotoDao.getLatestPhoto(vo.getTermId());
        if (photo != null) {
            long localPhotoTime = MyDateUtils.TimeMillSecond2Second(vo.getPhotoTime());
            log.info("请求时间:{}", localPhotoTime);
            log.info("装置凯斯处理时间:{}", photo.getRecvTime());
            hasNew = photo.getRecvTime().longValue() < localPhotoTime ? false : true;
            if (hasNew && photo.getMediaType() == 1) {
                if (!StringUtils.isNotBlank(photo.getThumb())) {
                    hasNew = false;
                }
            }
        } else {
            hasNew = false;
        }

        return Asserts.success(hasNew);
    }

    /**
     * 图片轮询接口
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<TerminalPhotosModel> getPhotoBanner(PageVo vo) {
        TerminalPhotosModel model = new TerminalPhotosModel();

        int pageindex = vo.getPageindex();
        int pagesize = vo.getPagesize();
        PageUtils.SetPage(pageindex, pagesize);

        List<ChannelAndTermDto> list = terminalsDao.selectChannelAndTermList(CommonStatus.EFFECTIVE.value());
        List<TerminalPhotosModel.PhotosBean> beans = new ArrayList<>();

        if (!CollectionUtil.isEmpty(list)) {
            Map<Integer, LineAndDyNameDto> lineMap = XyCache.lineMap;
            Map<String, TerminalChannelMapper> termchannelMapMap = XyCache.termchannelMapMap;
            List<Integer> termidlist = new ArrayList<>();
            for (ChannelAndTermDto item : list) {
                Integer termid = item.getTermid();
                termidlist.add(termid);
            }
            List<TermAndChannelLatestPhotoMapperDto> list2 = terminalPhotoDao.selectTermAndChannelLatestPhotoList(termidlist);
            for (ChannelAndTermDto item : list) {
                TerminalPhotosModel.PhotosBean photosBean = new TerminalPhotosModel.PhotosBean();
                Integer termid = item.getTermid();
                Integer channelid = item.getChannelid();

                photosBean.setTermid(termid);
                photosBean.setLineid(item.getLineid());
                photosBean.setChannnelname(item.getChannelname());
                if (termchannelMapMap != null) {
                    TerminalChannelMapper terminalChannelMapper = termchannelMapMap.get(termid + "#" + channelid);
                    if (terminalChannelMapper != null) {
                        photosBean.setAlias(terminalChannelMapper.getAlias());
                    } else {
                        photosBean.setAlias("");
                    }
                } else {
                    photosBean.setAlias("");
                }
                photosBean.setChannelid(channelid);
                photosBean.setDisplayname(item.getDisplayname());

                LineAndDyNameDto lineAndDyNameDto = lineMap.get(item.getLineid());
                if (lineAndDyNameDto != null) {
                    photosBean.setLinename(lineAndDyNameDto.getName());
                } else {
                    photosBean.setLinename("");
                }

                for (int y = 0; y < list2.size(); y++) {
                    TermAndChannelLatestPhotoMapperDto item2 = list2.get(y);
                    if (termid.intValue() == item2.getTermid().intValue() && item.getChannelid().intValue() == item2.getChannelid().intValue()) {
                        Integer mediatype = item2.getMediatype();
                        if (mediatype == 0 || mediatype == 1) {
                            photosBean.setPath(item2.getPath());
                            long recvtime = MyDateUtils.TimeSecond2MillSecond(item2.getRecvTime().longValue());
                            photosBean.setRecvTime(MyDateUtils.date(recvtime));
                            long phototime = MyDateUtils.TimeSecond2MillSecond(item2.getPhotoTime().longValue());
                            photosBean.setPhotoTime(MyDateUtils.date(phototime));
                            photosBean.setMediatype(mediatype);
                            if (mediatype.intValue() == 0) {
                                photosBean.setPath(photoaddress + item2.getPath());
                            } else {
                                photosBean.setPath(videoaddress + item2.getPath());
                            }
                            photosBean.setOrginalid(item2.getOrginalid());
                            photosBean.setPresetId(item2.getPresetId());
                        }
                        break;
                    }
                }
                beans.add(photosBean);
            }
        }
        model.setList(beans);
        PageInfo pageData = PageUtils.getPageData(list);
        int currentpage = pageData.getPageNum();
        model.setCurrentpage(currentpage);
        long total = pageData.getTotal();
        model.setTotal(total);

        int pageSize = pageData.getPageSize();
        model.setPagesize(pageSize);
        int pages = pageData.getPages();
        model.setTotalpage(pages);
        return Asserts.success(model);
    }

    @Override
    public ServiceBody<String> getPhotoTime(TerminalPhotoTimeVo vo) {
        List<TerminalPhotoScheduleDto> dtoList = terminalPhotoDao.selectPhotoSchedule(vo);

        for (int j = 0; j < dtoList.size(); j++) {
            TerminalPhotosTimeModel.PhotosTimeBean bean = new TerminalPhotosTimeModel.PhotosTimeBean();
            Short span = dtoList.get(j).getSpan();
            Date startTime = dtoList.get(j).getStartTime();
            Short startHour = Short.parseShort(MyDateUtils.parseHourAndMinute(startTime).split("/")[0]);
            Short startMin = Short.parseShort(MyDateUtils.parseHourAndMinute(startTime).split("/")[1]);


            Date endTime = dtoList.get(j).getEndTime();
            Short endTimeHour = Short.parseShort(MyDateUtils.parseHourAndMinute(endTime).split("/")[0]);
            Short endTimeMin = Short.parseShort(MyDateUtils.parseHourAndMinute(endTime).split("/")[1]);

            Short span1 = -1;
            Short span2 = -1;
            if (span / 60 > 0) {
                span1 = (short) (span / 60);
                span2 = (short) (span % 60);
            } else if (span < 60) {
                span1 = (short) 0;
                span2 = span;
            }
            String cmd = Constants.CMD + "schedule --flag=1 --cmdid=" + dtoList.get(j).getCmid() + " --channel=" + vo.getChannel()
                    + " --group=3 --hour1=" + startHour + " --min1=" + startMin + " --preset1=255 --hour2=" + endTimeHour + " --min2="
                    + endTimeMin + " --preset2=255 --hour3=" + span1 + " --min3=" + span2 + " --preset3=255";
            ProcessExecUtils.exec(cmd);
        }
        ;
        return Asserts.success("修改成功");
    }

    @Override
    public ServiceBody<GetModel> getPhotoQueryParam(ReturnedPhotoParamsGetVo vo) {
        GetModel model = new GetModel();
        int requestId = Constants.REQUEST_ID.addAndGet(1);
        String cmd = Constants.CMD + "imgparams --cmdid=" + vo.getCmdId() + " --clientid=10 --reqid=" + requestId + " --flag=0 --rf=7 --channel=" + vo.getChannelId();
        ProcessExecUtils.exec(cmd);
        model.setRequestId(requestId);
        /*
        TerminalPhotosParamsModel model = new TerminalPhotosParamsModel();
        PhotoParamsDto dto= terminalPhotoDao.selectPhotoParams(termId);
        if(dto!=null) {
            BeanUtils.copyProperties(dto, model);
        }*/
        return Asserts.success(model);
    }

    @Override
    public ServiceBody<String> addOrUpdatePhotoParams(PhotoParamsVo vo) {
        String cmd = Constants.CMD + "imgparams --flag=1 --cmdid=" + vo.getCmdId() + " --rf=7 --color=" + vo.getColor() + " --resolution=" + vo.getResolution()
                + " --luminance=" + vo.getLuminance() + " -contrast=" + vo.getContrast() + " --saturation=" + vo.getSaturation() + " --channel=" + vo.getChannelId();
        ProcessExecUtils.exec(cmd);
        return Asserts.success("设置成功");
    }

    @Override
    public ServiceBody<TerminalPhotosParamsModel> getLastedPhotoQueryParam(ReturnedPhotoParamsVo vo) {
        String result = terminalPhotoDao.getRequestResult(vo.getRequestId());
        TerminalPhotosParamsModel model = new TerminalPhotosParamsModel();
        if (StringUtils.isNotBlank(result)) {
            model = JSONObject.parseObject(result, TerminalPhotosParamsModel.class);
            model.setIsNew(true);
        } else {
            PhotoParamsDto dto = terminalPhotoDao.selectPhotoParams(vo);
            if (dto != null) {
                BeanUtils.copyProperties(dto, model);
            }
        }
        return Asserts.success(model);
    }

    @Override
    public ServiceBody<TerminalScheduleRuleTimeListModel> selectPhotoTime(TerminalReqPhotoTimeVo vo) {
        String result = terminalPhotoDao.getRequestResult(vo.getRequestId());//待修改
        TerminalScheduleRuleTimeListModel model = new TerminalScheduleRuleTimeListModel();
        if (StringUtils.isNotBlank(result)) {
            JSONObject resultObj = JSONObject.parseObject(result);
            if (null != resultObj.get("groupData")) {
                List<PhotoTimeResultDto> resultDtoList = JSONArray.parseArray(resultObj.get("groupData").toString(), PhotoTimeResultDto.class);
                if (CollectionUtil.isNotEmpty(resultDtoList)) {
                    List<String> resultList = Lists.newArrayList();
                    String startTimeStr = resultDtoList.get(0).getHour() + ":" + resultDtoList.get(0).getMinute() + ":00";
                    String endTimeStr = resultDtoList.get(1).getHour() + ":" + resultDtoList.get(1).getMinute() + ":00";
                    Date startTime = DateUtil.parseTime(startTimeStr);
                    Date endTime = DateUtil.parseTime(endTimeStr);
                    Integer span = resultDtoList.get(2).getHour() * 60 + resultDtoList.get(2).getMinute();
                    List<DateTime> dateTimes = MyDateUtils.rangeToList(startTime, endTime, DateField.MINUTE, span);
                    for (DateTime data : dateTimes) {
                        String dateTime = DateUtil.formatTime(data);
                        resultList.add(dateTime);
                    }
                    model.setList(resultList);
                    model.setIsNew(true);
                }
            }
        } else {
            TerminalAndChannelIdVo idVo = new TerminalAndChannelIdVo();
            BeanUtils.copyProperties(vo, idVo);
            ServiceBody<TerminalScheduleRuleTimeListModel> listModel = terminalScheduleRuleService.getChannelSchelduleRule(idVo);
            model = listModel.getData();
        }
        return Asserts.success(model);
    }

    @Override
    public ServiceBody<GetModel> selectPhotoTimeGet(TerminalPhotoTimeGetVo vo) {
        GetModel model = new GetModel();
        int requestId = Constants.REQUEST_ID.addAndGet(1);
        String cmd = Constants.CMD + "schedule --cmdid=" + vo.getCmdId() + " --reqid=" + requestId + " --clientid=10 --flag=0 --rf=7 --channel=" + vo.getChannel();
        ProcessExecUtils.exec(cmd);
        model.setRequestId(requestId);
        return Asserts.success(model);
    }


}
