package com.shxy.xymanager_service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.bean.copier.CopyOptions;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateTime;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageInfo;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.constant.Constants;
import com.shxy.xymanager_common.dto.DyLineAndTerminalNoHeartDto;
import com.shxy.xymanager_common.dto.PhotoMarkDto;
import com.shxy.xymanager_common.dto.TerminalInfoDto;
import com.shxy.xymanager_common.dto.TerminalsAndLineAndChannelDto;
import com.shxy.xymanager_common.entity.TerminalChannelMapper;
import com.shxy.xymanager_common.entity.Terminals;
import com.shxy.xymanager_common.enums.CommonStatus;
import com.shxy.xymanager_common.exception.Asserts;
import com.shxy.xymanager_common.model.*;
import com.shxy.xymanager_common.page.PageUtils;
import com.shxy.xymanager_common.util.MyDateUtils;
import com.shxy.xymanager_common.util.ProcessExecUtils;
import com.shxy.xymanager_common.util.StringUtils;
import com.shxy.xymanager_common.vo.*;
import com.shxy.xymanager_dao.dao.*;
import com.shxy.xymanager_service.service.TerminalService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import cn.hutool.core.date.DateUnit;

import javax.validation.constraints.NotBlank;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 设备服务实现层
 *
 * @author 晶晶
 */
@Slf4j
@Service
public class TerminalServiceImpl implements TerminalService {

    @Autowired
    private TerminalsDao terminalsDao;

    @Autowired
    private TerminalChannelMapperDao terminalChannelMapperDao;

    @Autowired
    TerminalPhotoDao terminalPhotoDao;

    @Autowired
    DyLevelDao dyLevelDao;

    @Value("${photo.address}")
    private String photoaddress;


    /**
     * 获取所有设备列表
     *
     * @return
     */
    @Override
    public ServiceBody<TerminalListModel> getTerminalList(PageVo vo) {
        TerminalListModel model = new TerminalListModel();
        int pageindex = vo.getPageindex();
        int pagesize = vo.getPagesize();
        PageUtils.SetPage(pageindex, pagesize);
        List<Integer> termidlist = new ArrayList<>();
        List<Terminals> list = terminalsDao.selectAll(CommonStatus.EFFECTIVE.value());
        if (CollectionUtil.isNotEmpty(list)) {
            for (Terminals item : list) {
                termidlist.add(item.getId());
            }
            List<TerminalsAndLineAndChannelDto> list2 = terminalsDao.selectTermAndLineList(termidlist, CommonStatus.EFFECTIVE.value());
            boolean empty = CollectionUtil.isEmpty(list2);
            if (empty) {
                model.setList(new ArrayList<>());
            } else {
                List<TerminalListModel.TerminalsBean> beans = BeanUtil.copyToList(list2, TerminalListModel.TerminalsBean.class, CopyOptions.create().ignoreCase());
                model.setList(beans);
            }
        } else {
            model.setList(new ArrayList<>());
        }
        PageInfo pageData = PageUtils.getPageData(list);
        int currentpage = pageData.getPageNum();
        model.setCurrentpage(currentpage);
        long total = pageData.getTotal();
        model.setTotal(total);

        int pageSize = pageData.getPageSize();
        model.setPagesize(pageSize);
        int pages = pageData.getPages();
        model.setTotalpage(pages);
        return Asserts.success(model);
    }

    /**
     * 添加设备信息
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<String> addTerminal(TerminalVo vo) {
        String cmdId = vo.getCmdId();
        Terminals terminals = new Terminals();
        BeanUtil.copyProperties(vo, terminals, CopyOptions.create().ignoreCase());
        Date time = new Date();
        Terminals bean = terminalsDao.selectByCmdid(cmdId, CommonStatus.EFFECTIVE.value());
        if (BeanUtil.isNotEmpty(bean)) {
            return Asserts.error("该装置已存在");
        }
        int i = terminalsDao.insertList(terminals, CommonStatus.EFFECTIVE.value(), time, time);
        Integer termid = terminals.getId();
        List<TerminalVo.ChannelItem> channelId = vo.getList();
        if (CollectionUtil.isNotEmpty(channelId)) {
            List<TerminalChannelMapper> list = new ArrayList<>();
            for (TerminalVo.ChannelItem item : channelId) {
                TerminalChannelMapper record = new TerminalChannelMapper();
                record.setChannelId(item.getId());
                record.setAlias(item.getAlias());
                record.setTermId(termid);
                list.add(record);
            }
            Date date = new Date();
            int i1 = terminalChannelMapperDao.insertList(list, date, date);
        }
        if (i != 0) {
            return Asserts.success("录入成功");
        } else {
            return Asserts.error("录入失败");
        }
    }

    /**
     * 修改装置信息
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<String> updateTerminal(UpdateTerminalVo vo) {
        Integer termid = vo.getId();
        List<UpdateTerminalVo.Item> channelId = vo.getList();
        Terminals terminals = new Terminals();
        BeanUtil.copyProperties(vo, terminals, true);
        int i = terminalsDao.updateByPrimaryKeySelective(terminals, new Date());
        terminalChannelMapperDao.deleteByTermId(termid);
        if (CollectionUtil.isNotEmpty(channelId)) {
            List<TerminalChannelMapper> list = new ArrayList<>();
            for (UpdateTerminalVo.Item item : channelId) {
                TerminalChannelMapper record = new TerminalChannelMapper();
                record.setChannelId(item.getId());
                record.setAlias(item.getAlias());
                record.setTermId(termid);
                list.add(record);
            }
            Date date = new Date();
            terminalChannelMapperDao.insertList(list, date, date);
        }
        if (i != 0) {
            return Asserts.success("修改成功");
        } else {
            return Asserts.error("修改失败");
        }
    }

    /**
     * 删除线路
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<String> deleteTerminal(TerminalIdListVo vo) {
        ArrayList<Terminals> list = new ArrayList<>();
        List<TerminalIdVo> beans = vo.getList();
        for (TerminalIdVo item : beans) {
            Terminals terminals = new Terminals();
            terminals.setId(item.getTermid());
            list.add(terminals);
        }
        int i = terminalsDao.deleteById(list, CommonStatus.DELETE.value(), new Date());
        if (i != 0) {
            return Asserts.success("删除成功");
        } else {
            return Asserts.error("删除失败");
        }
    }


    /**
     * 装置复位
     *
     * @param cmId
     * @return
     */
    @Override
    public ServiceBody<String> resetTerminal(String cmId) {
//        Cma cma = new Cma("47.96.238.157", 6891);
        String cmd = Constants.CMD + "reset --cmdid=" + cmId + " --mode=0";
        Integer retCode = ProcessExecUtils.exec(cmd);
//        boolean reset = cma.reset(vo.getTermid().toString(), (short) 0x01);
        if (retCode == 0) {
            return Asserts.success("装置复位成功");
        } else {
            return Asserts.error("装置复位失败");
        }
    }


    @Override
    public ServiceBody<TerminalStatusModel> getTerminalStatus(Integer termId) {
        TerminalStatusModel model = new TerminalStatusModel();
        String cmdId = terminalsDao.getCmdIdByTermId(termId);
        String cmd = Constants.CMD + "runningstatus --flag=0 --cmdid=" + cmdId;
        ProcessExecUtils.exec(cmd);

        /* TerminalModel model = new TerminalModel();*/
        /* TerminalInfoDto dto = terminalsDao.getTerminalInfo(termId);*/
        /*if (null != dto) {*/
        /*    BigInteger updatetime = MyDateUtils.TimeSecond2MillSecond(dto.getWsUpdateTime().longValue());
            BeanUtils.copyProperties(dto, model);*/
        DateTime now = DateTime.now();
        model.setQueryTime(now);
      /*      model.setWsUpdateTime(MyDateUtils.date(updatetime.longValue()).toString());
        }*/

        return Asserts.success(model);
    }

    @Override
    public ServiceBody<TerminalModel> getLastedTerminalStatus(TerminalStatusVo vo) {
       /* String result = terminalPhotoDao.getRequestResult(5);//待修改
        TerminalModel model = new TerminalModel();
        if (StringUtils.isNotBlank(result)) {
            model = JSONObject.parseObject(result, TerminalModel.class);
            model.setIsNew(true);
        } else {*/
        TerminalModel model = new TerminalModel();
        TerminalInfoDto dto = terminalsDao.getTerminalInfo(vo.getTermId());
        Boolean hasNew = false;
        if (null != dto) {
            BeanUtils.copyProperties(dto, model);
            BigInteger wsUpdateTime = dto.getWsUpdateTime();
            long queryTime = MyDateUtils.TimeMillSecond2Second(vo.getQueryTime());
            hasNew = wsUpdateTime.longValue() < queryTime ? false : true;

        }
        model.setIsNew(hasNew);
         /*   if (dto != null) {
                BeanUtils.copyProperties(dto, model);
            }
            model.setWsUpdateTime(MyDateUtils.TimeSecond2MillSecond(dto.getWsUpdateTime().longValue()));
        }*/
        return Asserts.success(model);
    }

    @Override
    public ServiceBody<TerminalUpdateModel> updateTerminalId(TerminalIdUpdateVo vo) {
        TerminalUpdateModel model = new TerminalUpdateModel();
        String cmd = Constants.CMD + "termid --flag=1 --cmdid=" + vo.getCmdId() + " --newcmdid=" + vo.getNewCmdId();
        ProcessExecUtils.exec(cmd);
        model.setTermId(vo.getTermId());

        int result = terminalsDao.updateCmd(vo);
        if (result > 0) {
            return Asserts.success(model);
        }

        return Asserts.error("装置ID修改失败");

    }

    /**
     * 根据通道编号获取装置列表
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<DyLineAndTermModel> getTermListByChannel(TerminalChannelIdVo vo) {
        Integer id = vo.getId();
        DyLineAndTermModel model = new DyLineAndTermModel();
        List<DyLineAndTerminalNoHeartDto> list = dyLevelDao.selectTreeListByChannelId(id, CommonStatus.EFFECTIVE.value());
        list.stream().forEach(var -> {
            var.getList().forEach(item -> {
                item.getList().forEach(terminalsWithHeart -> {
                    Long lastheartbeat = terminalsWithHeart.getLastheartbeat();
                    if (!BeanUtil.isEmpty(lastheartbeat)) {
                        long time = MyDateUtils.TimeSecond2MillSecond(lastheartbeat);
                        DateTime date = MyDateUtils.date(time);
                        long between = MyDateUtils.between(MyDateUtils.getNowDate(), date, DateUnit.MINUTE);
                        if (between > 30) {
                            terminalsWithHeart.setOnlinestatus(CommonStatus.DELETE.value());
                        } else {
                            terminalsWithHeart.setOnlinestatus(CommonStatus.EFFECTIVE.value());
                        }
                    }


                });
            });
        });
        boolean empty = CollectionUtil.isEmpty(list);
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            List<DyLineAndTermModel.DyListBean> beans = BeanUtil.copyToList(list, DyLineAndTermModel.DyListBean.class, CopyOptions.create().ignoreCase());

            model.setList(beans);
        }
        return Asserts.success(model);
    }

    @Override
    public ServiceBody<GetModel> terminalIdGet(TerminalIdUpdateVo vo) {
        int requestId = Constants.REQUEST_ID.addAndGet(1);
        String cmd = Constants.CMD + "termid --clientid=10 --flag=0 --cmdid=" + vo.getCmdId() + " --reqid=" + requestId;
        ProcessExecUtils.exec(cmd);
        GetModel model = new GetModel();
        model.setRequestId(requestId);
        return Asserts.success(model);
    }

    @Override
    public ServiceBody<TerminalIdModel> selectTerminalId(Integer requestId) {
        String result = terminalPhotoDao.getRequestResult(requestId);
        TerminalIdModel model = new TerminalIdModel();
        if (StringUtils.isNotBlank(result)) {
            model = JSONObject.parseObject(result, TerminalIdModel.class);
            model.setIsNew(true);
        }
        return Asserts.success(model);
    }

    @Override
    @Transactional
    public ServiceBody<String> updateCoordinate(PhotoMarkVo vo) {
        Date date = new Date();
        vo.setCreateTime(date);
        if (null != vo.getId()) {
            terminalPhotoDao.deleteByMarkId(vo.getId());
            terminalPhotoDao.updatePhotoMark(vo);
        } else {
            terminalPhotoDao.addPhotoMark(vo);

        }
        if (CollectionUtil.isNotEmpty(vo.getList())) {
            terminalPhotoDao.addPhotoMarkPath(vo.getList(), vo.getId());
        }

        return Asserts.success("保存成功");
    }

    @Override
    public ServiceBody<PhotoMarkModel> getCoordinate(MarkReqVo vo) {
        PhotoMarkModel model = new PhotoMarkModel();
        PhotoMarkDto dto = null;
        if (vo.getNeedPic() == 0) {
            dto = terminalPhotoDao.selectPhotoMark(vo);
            if (null != dto && StringUtils.isNotBlank(dto.getPath())) {
                dto.setPath(photoaddress + dto.getPath());
            }
        } else {
            dto = terminalPhotoDao.selectPhotoWithoutPic(vo);
        }

        if (null != dto) {
            BeanUtils.copyProperties(dto, model);
        }
        return Asserts.success(model);
    }
}

