package com.shxy.xymanager_service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.bean.copier.CopyOptions;
import cn.hutool.core.collection.CollectionUtil;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.entity.Terminals;
import com.shxy.xymanager_common.enums.CommonStatus;
import com.shxy.xymanager_common.exception.Asserts;
import com.shxy.xymanager_common.model.TerminalListModel;
import com.shxy.xymanager_common.vo.TerminalIdListVo;
import com.shxy.xymanager_dao.dao.TerminalsDao;
import com.shxy.xymanager_service.service.TerminalStatusService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 设备服务实现层
 *
 * @author 晶晶
 */
@Slf4j
@Service
public class TerminalStatusServiceImpl implements TerminalStatusService {

    @Autowired
    private TerminalsDao terminalsDao;

    /**
     * 获取所有设备列表
     *
     * @return
     */
    @Override
    public ServiceBody<TerminalListModel> getTerminalList() {
        TerminalListModel terminalListModel = new TerminalListModel();
        List<Terminals> terminals = terminalsDao.selectAll(CommonStatus.EFFECTIVE.value());
        boolean empty = CollectionUtil.isEmpty(terminals);
        if (empty) {
            terminalListModel.setList(new ArrayList<>());
        } else {
            List<TerminalListModel.TerminalsBean> list = BeanUtil.copyToList(terminals, TerminalListModel.TerminalsBean.class, CopyOptions.create().ignoreCase());
            terminalListModel.setList(list);
        }
        return Asserts.success(terminalListModel);
    }


    /**
     * 删除装置
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<String> deleteLine(TerminalIdListVo vo) {
        List<Terminals> list = BeanUtil.copyToList(vo.getList(), Terminals.class);
        int i = terminalsDao.deleteById(list,CommonStatus.DELETE.value(),new Date());
        if (i != 0) {
            return Asserts.success("删除成功");
        } else {
            return Asserts.error("删除失败");
        }
    }

}

